@@ -3,12 +3,10 @@ from typing import Any
 import numpy as np
 from numpy.typing import NDArray
 
-__all__ = [
-    "cosine",
-]
+__all__ = ("cosine_similarity",)
 
 
-def cosine(
+def cosine_similarity(
     a: list[NDArray[Any]] | NDArray[Any],
     b: list[NDArray[Any]] | NDArray[Any],
 ) -> NDArray[Any]:
